LamsonProject: About Lamson

#

# About Lamson

Lamson started more than a year ago as a fun side project of mine after a few evil experiences with sendmail and various mailing list software. I realized that e-mail systems didn’t have anything like a modern “framework” for building applications. Rather than replicate the mess of aliases, pipes, processes, and nasty m4 macros that currently existed, I decided to write something different.

Lamson was originally called “Son Of Sam”, but that name proved too difficult to work with as a project name. Apparently people don’t like their software named after serial killers (actually, that was his dog’s name).

“Lamson Tubes” is a colloquial name for Pneumatic Tubes which were used last century to deliver mail, packages, and hazardous material to the corporate world. They are still in use today.

Now Lamson is a fully functioning SMTP server, relay, proxy, and e-mail application framework. It supports most RDBMS, has templates, and is easy to manage and deploy. Lamson is smarter than most any e-mail processing system out there thanks to Python.

However, as great as Lamson is for processing email intelligently, it isn’t the best solution for delivering mail. There is 30+ years of SMTP lore and myth stored in the code of mail servers such as Postfix and Exim that would take years to replicate and make efficient. Being a practical project, Lamson defers to much more capable SMTP servers for the grunt work of getting the mail to the final recipient.

I currently use Lamson in my own work, but I’m always looking for people doing interesting things with e-mail. Even if you’re a spammer, or someone trying to destroy the spammers, I want to hear from you.

If you’ve got something interesting, feel free to contact me and talk about it.